@@ -1,4 +1,4 @@
 from __future__ import absolute_import
 
-from .basescript import BaseScript
+from .basescript import BaseScript, main
 from .log import init_logger, get_logger
